﻿using System;
using System.Collections;

namespace RH.ImportGoogleAnalytics
{
	/// <summary>
	/// Source: http://www.dotnetscraps.com/dotnetscraps/post/A-C-Argument-Parser-for-a-Windows-Console-Application.aspx
	/// </summary>
	class ArgumentParser
	{
		/// <summary>
		/// Method which will parse the string input and return a hashtable
		/// </summary>
		/// <param name="args"></param>
		/// <returns></returns>
		public static Hashtable Parse(String[] args)
		{
			var argTable = new Hashtable();
			try
			{
				string value;

				if ((null == args) || args.Length == 0)
				{
					argTable.Add("Invalid", "true");
					return argTable;
				}


				foreach (string s in args)
				{

					if ((s.StartsWith("-") || s.StartsWith("/")) && (s.Contains("=") && !s.Contains("?")))
					{
						// Strip off - or /
						string key = s.Substring(1, s.Length - 1);
						string[] keyvalue = key.Split('=');
						key = keyvalue[0];
						value = keyvalue[1];

						if (value == null || value.Trim() == "")
						{
							argTable.Add("Invalid", "true");
							return argTable;
						}

						AddKeyValuePair(argTable, key, value);

					}
					else
					{
						// otherwise this is invalid value
						if (s.Contains("?"))
						{
							AddKeyValuePair(argTable, "?", "true");
						}
						else
						{
							AddKeyValuePair(argTable, "Invalid", "true");
						}
					}
				}
				// return the hashtable with the command line arguments in it.
				return argTable;
			}
			catch (ArgumentOutOfRangeException outOfRangeEx)
			{
				Console.WriteLine("Arguments out of range, please check error log" + outOfRangeEx.Message + Environment.NewLine + outOfRangeEx.StackTrace);
				return argTable;
			}
			catch (Exception ex)
			{
				Console.WriteLine(ex.Message + Environment.NewLine + ex.StackTrace);
				return argTable;
			}
		}

		/// <summary>
		/// Add the arguments in the form of a keyvalue pair to Hashtable
		/// </summary>
		/// <param name="argTable"></param>
		/// <param name="key"></param>
		/// <param name="value"></param>
		private static void AddKeyValuePair(Hashtable argTable, string key, string value)
		{
			try
			{
				if (!argTable.ContainsKey(key))
				{
					// add this to table
					argTable.Add(key, value);
				}
				else
				{
					//substitute the value with the latest one
					argTable[key] = value;
				}
			}
			catch (ArgumentException argEx)
			{
				Console.WriteLine(argEx.Message + Environment.NewLine + argEx.StackTrace);
			}
			catch (Exception ex)
			{
				Console.WriteLine(ex.Message + Environment.NewLine + ex.StackTrace);
			}
		}
	}

}
